==> kdepim-addons-17.03.90.tar.xz: kdepim-addons-17.03.90/plugins/messageviewer/bodypartformatter/gnupgwks/pgpkeyformatter.h <==
/*
  Copyright (c) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   This library is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
   License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/

#ifndef PGPKEYFORMATTER_H_
#define PGPKEYFORMATTER_H_

#include <MimeTreeParser/BodyPartFormatter>

class PgpKeyMessagePart;

class ApplicationPGPKeyFormatter : public MimeTreeParser::Interface::BodyPartFormatter
{
public:
    ApplicationPGPKeyFormatter() = default;

    MimeTreeParser::Interface::BodyPartFormatter::Result format(MimeTreeParser::Interface::BodyPart *part,
            MimeTreeParser::HtmlWriter *writer) const Q_DECL_OVERRIDE;
    MimeTreeParser::Interface::BodyPartFormatter::Result format(MimeTreeParser::Interface::BodyPart *part,
            MimeTreeParser::HtmlWriter *writer,
            QObject *asyncResultObserver) const Q_DECL_OVERRIDE;

private:
    QString render(const PgpKeyMessagePart &mp) const;
};

#endif

==> kdepim-addons_17.12.3.orig.tar.xz: kdepim-addons-17.12.3/plugins/messageviewer/bodypartformatter/gnupgwks/pgpkeyformatter.h <==
/*
  Copyright (c) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   This library is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
   License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/

#ifndef PGPKEYFORMATTER_H_
#define PGPKEYFORMATTER_H_

#include <MimeTreeParser/BodyPartFormatter>
#include <MessageViewer/MessagePartRendererBase>

class PgpKeyMessagePart;

class ApplicationPGPKeyFormatter : public MimeTreeParser::Interface::BodyPartFormatter, public MessageViewer::MessagePartRendererBase
{
public:
    ApplicationPGPKeyFormatter() = default;

    MimeTreeParser::MessagePartPtr process(MimeTreeParser::Interface::BodyPart &part) const override;
    bool render(const MimeTreeParser::MessagePartPtr &msgPart, MimeTreeParser::HtmlWriter *htmlWriter, MessageViewer::RenderContext *context) const override;

private:
    QString render(const PgpKeyMessagePart &mp) const;
};

#endif
